# Installation

```bash
pip install beamz
```

is the easiest way to install BEAMZ since you only need [Python 3.8 or higher](https://www.python.org/downloads/) and [pip (Python package installer)](https://pip.pypa.io/en/stable/installation/).

Alternatively, you can install BEAMZ directly from the source code. To do so, clone the repository:
```bash
git clone https://github.com/QuentinWach/beamz.git
cd beamz
```
and then install it using:
```bash
pip install -e .
```

You can verify that Beamz is installed correctly, you can run:
```python
import beamz
print(beamz.__version__)
```

For more help, please visit our [GitHub issues page](https://github.com/QuentinWach/beamz/issues). 